@@ -15,7 +15,4 @@
 #' @name favorite_bars
 #' @usage favorite_bars
 #' @format A \code{data frame} with 5 observations and 2 variables.
-#' @examples
-#' data(favorite_bars)
-#' favorite_bars
-NULL
+"favorite_bars"
