@@ -18,7 +18,5 @@
 #' @name unemployment
 #' @usage unemployment
 #' @format A \code{data.frame} with 3 variables and 3.216 observations.
-#' @examples
-#' data(unemployment)
-#' unemployment
-NULL
+#' @source \url{https://www.highcharts.com/samples/data/jsonp.php?filename=us-counties-unemployment.json}
+"unemployment"
